import sys
import subprocess

from ss_py.ssprofile import SSProfile

PATH_BASE = './'
# PATH_BASE = '/etc/ss_py/'
FILE_PROFILE = PATH_BASE + 'profile.json'
FILE_SSERVER_PID = PATH_BASE + 'sserverpid.txt'

class SSTool(object):
    def __init__(self):
        self.profile = SSProfile(FILE_PROFILE)

    def _checkPortRanges(self, port):
        port = int(port)
        if port > 0 and port <= 65536:
            return True
        return False

    def startSS(self):
        cmd = 'ssserver -qq -c ' + FILE_PROFILE + ' 2>/dev/null >/dev/null & echo $! > ' + FILE_SSERVER_PID
        res = subprocess.call(cmd, shell=True)
        return res

    def stopSS(self):
        cmd = 'kill `cat ' + FILE_SSERVER_PID + '`'
        res = subprocess.call(cmd, shell=True)
        return
    
    def addDelPort(self, isAdd, port, pwd):
        if self._checkPortRanges(port) == False:
            return False
        if isAdd:
            self.profile.addPort(port, pwd)
        else:
            self.profile.delPort(port)
        self.profile.save(FILE_PROFILE)
        self.stopSS()
        self.startSS()
    
    





from aigpy import cmdHelper
from ss_py.sstool import SSTool

def main(argv=None):
    tool = SSTool()

    print('1  开始')
    print('2  停止')
    print('3  添加')
    print('4  删除')
    
    choice = int(cmdHelper.myinput('选择:'))
    if choice == 1:
        tool.startSS()
    elif choice == 2:
        tool.stopSS()
    elif choice == 3:
        port = cmdHelper.myinput('端口:')
        pwd = cmdHelper.myinput('密码:')
        tool.addDelPort(True, port, pwd)
    elif choice == 4:
        port = cmdHelper.myinput('端口:')
        tool.addDelPort(False, port, None)

__all__ = ['main']
